@@ -71,7 +71,7 @@ const char* _regionNames[] = {"DistRegionAck"};
 
 #include "LocatorHelper.hpp"
 
-void verifyGetAll(std::shared_ptr<Region> region, const char** _vals,
+void verifyGetAll(std::shared_ptr<Region> region, const char** _values,
                   int startIndex,
                   std::shared_ptr<Cacheable> callBack = nullptr) {
   auto keyPtr0 = CacheableKey::create(_keys[0]);
@@ -84,25 +84,19 @@ void verifyGetAll(std::shared_ptr<Region> region, const char** _vals,
   keys1.push_back(keyPtr2);
 
   std::unordered_map<std::string, std::string> expected;
-  expected[_keys[0]] = _vals[startIndex + 0];
-  expected[_keys[1]] = _vals[startIndex + 1];
+  expected[_keys[0]] = _values[startIndex + 0];
+  expected[_keys[1]] = _values[startIndex + 1];
 
   auto valuesMap = region->getAll(keys1, callBack);
   if (valuesMap.size() == keys1.size()) {
-    char buf[2048];
     for (const auto& iter : valuesMap) {
       const auto key = std::dynamic_pointer_cast<CacheableKey>(iter.first);
-      const auto actualKey = key->toString().c_str();
       const auto& mVal = iter.second;
       if (mVal != nullptr) {
-        const auto expectedVal = expected[actualKey].c_str();
-        const auto actualVal = mVal->toString().c_str();
-        sprintf(buf, "value from map %s , expected value %s ", actualVal,
-                expectedVal);
-        LOG(buf);
-        ASSERT(strcmp(actualVal, expectedVal) == 0, "value not matched");
+        LOG(std::string("Value from map ") + mVal->toString() + ", expected value " + expected[key->toString()]);
+        ASSERT(mVal->toString() == expected[key->toString()], "value not matched");
       } else {
-        ASSERT(strcmp(actualKey, "keyNotThere") == 0,
+        ASSERT(key->toString() == "keyNotThere",
                "keyNotThere value is not null");
       }
     }
@@ -110,9 +104,9 @@ void verifyGetAll(std::shared_ptr<Region> region, const char** _vals,
 }
 
 void verifyGetAllWithCallBackArg(std::shared_ptr<Region> region,
-                                 const char** vals, int startIndex,
+                                 const char** values, int startIndex,
                                  std::shared_ptr<Cacheable> callBack) {
-  verifyGetAll(region, vals, startIndex, callBack);
+  verifyGetAll(region, values, startIndex, callBack);
 }
 
 void createPooledRegion(const char* name, bool ackMode, const char* locators,
