@@ -20,6 +20,9 @@
 #include <algorithm>
 #include <thread>
 
+#include <ace/INET_Addr.h>
+#include <ace/OS_NS_unistd.h>
+
 #include <geode/AuthInitialize.hpp>
 #include <geode/PoolManager.hpp>
 #include <geode/ResultCollector.hpp>
@@ -166,12 +169,7 @@ ThinClientPoolDM::ThinClientPoolDM(const char* name,
   // to set security flag at pool level
   m_isSecurityOn = cacheImpl->getAuthInitialize() != nullptr;
 
-  ACE_TCHAR hostName[256];
-  ACE_OS::hostname(hostName, sizeof(hostName) - 1);
-  ACE_INET_Addr driver(hostName);
-
-  uint16_t hostPort = 0;
-  auto&& durableId = sysProp.durableClientId();
+  const auto& durableId = sysProp.durableClientId();
 
   std::string clientDurableId = durableId;
   if (!m_poolName.empty()) {
@@ -180,7 +178,7 @@ ThinClientPoolDM::ThinClientPoolDM(const char* name,
 
   const auto durableTimeOut = sysProp.durableTimeout();
   m_memId = cacheImpl->getClientProxyMembershipIDFactory().create(
-      hostName, driver, hostPort, clientDurableId.c_str(), durableTimeOut);
+      clientDurableId.c_str(), durableTimeOut);
 
   if (m_attrs->m_initLocList.empty() && m_attrs->m_initServList.empty()) {
     std::string msg = "No locators or servers provided for pool named ";
@@ -188,7 +186,9 @@ ThinClientPoolDM::ThinClientPoolDM(const char* name,
     throw IllegalStateException(msg);
   }
   reset();
-  m_locHelper = new ThinClientLocatorHelper(m_attrs->m_initLocList, this);
+  m_locHelper = new ThinClientLocatorHelper(m_attrs->m_initLocList,
+                                            m_attrs->m_sniProxyHost,
+                                            m_attrs->m_sniProxyPort, this);
 
   m_stats = new PoolStats(
       cacheImpl->getStatisticsManager().getStatisticsFactory(), m_poolName);
@@ -369,7 +369,7 @@ void ThinClientPoolDM::startBackgroundThreads() {
   // starting chunk processing helper thread
   ThinClientBaseDM::init();
 
-  if (m_clientMetadataService != nullptr) {
+  if (m_clientMetadataService) {
     m_clientMetadataService->start();
   }
 }
@@ -490,7 +490,7 @@ void ThinClientPoolDM::cleanStaleConnections(std::atomic<bool>& isRunning) {
               to_string(_nextIdle).c_str());
   }
 
-  LOGDEBUG("Pool size is %d, pool counter is %d", size(), m_poolSize.load());
+  LOGDEBUG("Pool size is %zu, pool counter is %d", size(), m_poolSize.load());
 }
 
 void ThinClientPoolDM::cleanStickyConnections(std::atomic<bool>&) {}
@@ -510,7 +510,6 @@ void ThinClientPoolDM::restoreMinConnections(std::atomic<bool>& isRunning) {
   int restored = 0;
 
   if (m_poolSize < min) {
-    ACE_Guard<ACE_Recursive_Thread_Mutex> poolguard(m_queueLock);
     while (m_poolSize < min && limit-- && isRunning) {
       TcrConnection* conn = nullptr;
       bool maxConnLimit = false;
@@ -524,14 +523,14 @@ void ThinClientPoolDM::restoreMinConnections(std::atomic<bool>& isRunning) {
   }
 
   LOGDEBUG("Restored %d connections", restored);
-  LOGDEBUG("Pool size is %d, pool counter is %d", size(), m_poolSize.load());
+  LOGDEBUG("Pool size is %zu, pool counter is %d", size(), m_poolSize.load());
 }
 
 void ThinClientPoolDM::manageConnectionsInternal(std::atomic<bool>& isRunning) {
   try {
     LOGFINE(
         "ThinClientPoolDM::manageConnections(): checking connections in pool "
-        "queue %d",
+        "queue %zu",
         size());
 
     cleanStaleConnections(isRunning);
@@ -569,7 +568,8 @@ std::string ThinClientPoolDM::selectEndpoint(
       throw IllegalStateException("Locator query failed");
     }
     // Update Locator stats
-    getStats().setLocators((m_locHelper)->getCurLocatorsNum());
+    getStats().setLocators(
+        static_cast<int32_t>(m_locHelper->getCurLocatorsNum()));
     getStats().incLoctorResposes();
 
     std::string epNameStr = outEndpoint.getServerName() + ":" +
@@ -607,8 +607,7 @@ std::string ThinClientPoolDM::selectEndpoint(
 }
 
 void ThinClientPoolDM::addConnection(TcrConnection* conn) {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(getPoolLock());
-
+  std::lock_guard<decltype(mutex_)> lock(mutex_);
   put(conn, false);
   ++m_poolSize;
 }
@@ -672,11 +671,12 @@ GfErrType ThinClientPoolDM::sendRequestToAllServers(
         err == GF_NOT_AUTHORIZED_EXCEPTION ||
         err == GF_AUTHENTICATION_REQUIRED_EXCEPTION) {
       finalErrorReturn = err;
-    } else if (!(finalErrorReturn == GF_AUTHENTICATION_FAILED_EXCEPTION ||
-                 finalErrorReturn == GF_NOT_AUTHORIZED_EXCEPTION ||
-                 finalErrorReturn ==
-                     GF_AUTHENTICATION_REQUIRED_EXCEPTION))  // returning auth
-                                                             // errors
+    } else if ((err != GF_NOERR) &&
+               (!(finalErrorReturn == GF_AUTHENTICATION_FAILED_EXCEPTION ||
+                  finalErrorReturn == GF_NOT_AUTHORIZED_EXCEPTION ||
+                  finalErrorReturn ==
+                      GF_AUTHENTICATION_REQUIRED_EXCEPTION)))  // returning auth
+                                                               // errors
     // to client..preference
     // over other errors..
     {
@@ -803,8 +803,10 @@ void ThinClientPoolDM::destroy(bool keepAlive) {
       // m_clientMetadataService = nullptr;
     }
     // closing all the thread local connections ( sticky).
-    LOGDEBUG("ThinClientPoolDM::destroy( ): closing FairQueue, pool size = %d",
-             m_poolSize.load());
+    LOGDEBUG(
+        "ThinClientPoolDM::destroy( ): closing ConnectionQueue, pool size = "
+        "%d",
+        m_poolSize.load());
     close();
     LOGDEBUG("ThinClientPoolDM::destroy( ): after close ");
 
@@ -894,7 +896,7 @@ int32_t ThinClientPoolDM::GetPDXIdForType(
   throwExceptionIfError("Operation Failed", sendSyncRequest(request, reply));
 
   if (reply.getMessageType() == TcrMessage::EXCEPTION) {
-    LOGDEBUG("ThinClientPoolDM::GetPDXTypeById: Exception = %s ",
+    LOGDEBUG("ThinClientPoolDM::GetPDXTypeById: Exception = " +
              reply.getException());
     throw IllegalStateException("Failed to register PdxSerializable Type");
   }
@@ -930,7 +932,7 @@ void ThinClientPoolDM::AddPdxType(std::shared_ptr<Serializable> pdxType,
   throwExceptionIfError("Operation Failed", sendSyncRequest(request, reply));
 
   if (reply.getMessageType() == TcrMessage::EXCEPTION) {
-    LOGDEBUG("ThinClientPoolDM::GetPDXTypeById: Exception = %s ",
+    LOGDEBUG("ThinClientPoolDM::GetPDXTypeById: Exception = " +
              reply.getException());
     throw IllegalStateException("Failed to register PdxSerializable Type");
   }
@@ -947,7 +949,7 @@ std::shared_ptr<Serializable> ThinClientPoolDM::GetPDXTypeById(int32_t typeId) {
   throwExceptionIfError("Operation Failed", sendSyncRequest(request, reply));
 
   if (reply.getMessageType() == TcrMessage::EXCEPTION) {
-    LOGDEBUG("ThinClientPoolDM::GetPDXTypeById: Exception = %s ",
+    LOGDEBUG("ThinClientPoolDM::GetPDXTypeById: Exception = " +
              reply.getException());
     throw IllegalStateException("Failed to understand PdxSerializable Type");
   }
@@ -967,7 +969,7 @@ int32_t ThinClientPoolDM::GetEnumValue(std::shared_ptr<Serializable> enumInfo) {
   throwExceptionIfError("Operation Failed", sendSyncRequest(request, reply));
 
   if (reply.getMessageType() == TcrMessage::EXCEPTION) {
-    LOGDEBUG("ThinClientPoolDM::GetEnumValue: Exception = %s ",
+    LOGDEBUG("ThinClientPoolDM::GetEnumValue: Exception = " +
              reply.getException());
     throw IllegalStateException("Failed to register Pdx enum Type");
   }
@@ -1002,8 +1004,7 @@ std::shared_ptr<Serializable> ThinClientPoolDM::GetEnum(int32_t val) {
   throwExceptionIfError("Operation Failed", sendSyncRequest(request, reply));
 
   if (reply.getMessageType() == TcrMessage::EXCEPTION) {
-    LOGDEBUG("ThinClientPoolDM::GetEnum: Exception = %s ",
-             reply.getException());
+    LOGDEBUG("ThinClientPoolDM::GetEnum: Exception = " + reply.getException());
     throw IllegalStateException("Failed to understand enum Type");
   }
 
@@ -1023,8 +1024,7 @@ void ThinClientPoolDM::AddEnum(std::shared_ptr<Serializable> enumInfo,
   throwExceptionIfError("Operation Failed", sendSyncRequest(request, reply));
 
   if (reply.getMessageType() == TcrMessage::EXCEPTION) {
-    LOGDEBUG("ThinClientPoolDM::AddEnum: Exception = %s ",
-             reply.getException());
+    LOGDEBUG("ThinClientPoolDM::AddEnum: Exception = " + reply.getException());
     throw IllegalStateException("Failed to register enum Type");
   }
 }
@@ -1093,7 +1093,7 @@ TcrEndpoint* ThinClientPoolDM::getSingleHopServer(
     std::shared_ptr<BucketServerLocation>& serverlocation,
     std::set<ServerLocation>& excludeServers) {
   const std::shared_ptr<CacheableKey>& key = request.getKeyRef();
-  if (m_clientMetadataService == nullptr || key == nullptr) return nullptr;
+  if (!m_clientMetadataService || key == nullptr) return nullptr;
   auto r = request.getRegion();
   auto region = nullptr == r ? nullptr : r->shared_from_this();
   TcrEndpoint* ep = nullptr;
@@ -1128,7 +1128,7 @@ TcrEndpoint* ThinClientPoolDM::getEndPoint(
 
     ep = getEndpoint(serverLocation->getEpString());
     if (ep) {
-      LOGDEBUG("Endpoint for single hop is %p", ep);
+      LOGDEBUG("Endpoint for single hop is %s", ep->name().c_str());
       return ep;
     }
 
@@ -1189,7 +1189,7 @@ GfErrType ThinClientPoolDM::sendSyncRequest(TcrMessage& request,
   if (!request.forTransaction() && m_attrs->getPRSingleHopEnabled() &&
       (type == TcrMessage::GET_ALL_70 ||
        type == TcrMessage::GET_ALL_WITH_CALLBACK) &&
-      m_clientMetadataService != nullptr) {
+      m_clientMetadataService) {
     GfErrType error = GF_NOERR;
 
     auto region =
@@ -1428,9 +1428,10 @@ GfErrType ThinClientPoolDM::sendSyncRequest(
             GF_SAFE_DELETE_CON(conn);
           }
           excludeServers.insert(ServerLocation(ep->name()));
+          removeEPFromMetadataIfError(error, ep);
         }
       } else {
-        return error;  // server exception while sending credentail message to
+        return error;  // server exception while sending credential message to
       }
       // server...
     }
@@ -1460,7 +1461,7 @@ GfErrType ThinClientPoolDM::sendSyncRequest(
           "reply Metadata version is %d & bsl version is %d "
           "reply.isFEAnotherHop()=%d",
           reply.getMetaDataVersion(), version, reply.isFEAnotherHop());
-      if (m_clientMetadataService != nullptr && request.forSingleHop() &&
+      if (m_clientMetadataService && request.forSingleHop() &&
           (reply.getMetaDataVersion() != 0 ||
            (request.getMessageType() == TcrMessage::EXECUTE_REGION_FUNCTION &&
             request.getKeyRef() != nullptr && reply.isFEAnotherHop()))) {
@@ -1527,6 +1528,17 @@ GfErrType ThinClientPoolDM::sendSyncRequest(
   return error;
 }
 
+void ThinClientPoolDM::removeEPFromMetadataIfError(const GfErrType& error,
+                                                   const TcrEndpoint* ep) {
+  if ((error == GF_IOERR || error == GF_TIMEOUT) && (m_clientMetadataService)) {
+    auto sl = std::make_shared<BucketServerLocation>(ep->name());
+    LOGINFO("Removing bucketServerLocation %s due to %s",
+            sl->toString().c_str(),
+            (error == GF_IOERR ? "GF_IOERR" : "GF_TIMEOUT"));
+    m_clientMetadataService->removeBucketServerLocation(sl);
+  }
+}
+
 void ThinClientPoolDM::removeEPConnections(int numConn,
                                            bool triggerManageConn) {
   // TODO: Delete EP
@@ -1624,7 +1636,6 @@ GfErrType ThinClientPoolDM::getConnectionToAnEndPoint(std::string epNameStr,
 GfErrType ThinClientPoolDM::createPoolConnectionToAEndPoint(
     TcrConnection*& conn, TcrEndpoint* theEP, bool& maxConnLimit,
     bool appThreadrequest) {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_queueLock);
   GfErrType error = GF_NOERR;
   conn = nullptr;
   int min = 0;
@@ -1687,7 +1698,6 @@ void ThinClientPoolDM::reducePoolSize(int num) {
 GfErrType ThinClientPoolDM::createPoolConnection(
     TcrConnection*& conn, std::set<ServerLocation>& excludeServers,
     bool& maxConnLimit, const TcrConnection* currentserver) {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_queueLock);
   GfErrType error = GF_NOERR;
   int max = m_attrs->getMaxConnections();
   if (max == -1) {
@@ -1788,7 +1798,7 @@ TcrConnection* ThinClientPoolDM::getConnectionFromQueue(
     bool& maxConnLimit) {
   std::chrono::microseconds timeoutTime = m_attrs->getFreeConnectionTimeout();
 
-  getStats().setCurWaitingConnections(waiters());
+  getStats().incCurWaitingConnections();
   getStats().incWaitingConnections();
 
   /*get the start time for connectionWaitTime stat*/
@@ -1804,6 +1814,7 @@ TcrConnection* ThinClientPoolDM::getConnectionFromQueue(
                             getStats().getTotalWaitingConnTimeId(),
                             sampleStartNanos);
   }
+  getStats().decCurWaitingConnections();
   return mp;
 }
 
@@ -1852,7 +1863,6 @@ GfErrType ThinClientPoolDM::sendRequestToEP(const TcrMessage& request,
         _GEODE_SAFE_DELETE(conn);
       }
       if (putConnInPool) {
-        ACE_Guard<ACE_Recursive_Thread_Mutex> guard(getPoolLock());
         reducePoolSize(1);
       }
       currentEndpoint->setConnectionStatus(false);
@@ -1935,9 +1945,9 @@ GfErrType ThinClientPoolDM::sendRequestToEP(const TcrMessage& request,
     } else if (error != GF_NOERR) {
       currentEndpoint->setConnectionStatus(false);
       if (putConnInPool) {
-        ACE_Guard<ACE_Recursive_Thread_Mutex> guard(getPoolLock());
         removeEPConnections(1);
       }
+      removeEPFromMetadataIfError(error, currentEndpoint);
     }
 
     if (error == GF_NOERR || error == GF_CACHESERVER_EXCEPTION ||
@@ -1990,13 +2000,11 @@ TcrEndpoint* ThinClientPoolDM::addEP(const std::string& endpointName) {
 }
 
 void ThinClientPoolDM::netDown() {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> guard(getPoolLock());
   close();
   reset();
 }
 
 void ThinClientPoolDM::pingServerLocal() {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(getPoolLock());
   std::lock_guard<decltype(m_endpointsLock)> guard(m_endpointsLock);
   for (auto& it : m_endpoints) {
     auto endpoint = it.second;
@@ -2096,7 +2104,6 @@ bool ThinClientPoolDM::canItBeDeleted(TcrConnection* conn) {
   if (conn && candidateForDeletion) {
     TcrEndpoint* endPt = conn->getEndpointObject();
     {
-      ACE_Guard<ACE_Recursive_Thread_Mutex> poolguard(m_queueLock);  // PXR
       std::lock_guard<decltype(endPt->getQueueHostedMutex())> guardQueue(
           endPt->getQueueHostedMutex());
       bool queue = endPt->isQueueHosted();
@@ -2127,12 +2134,12 @@ bool ThinClientPoolDM::excludeConnection(
 }
 
 TcrConnection* ThinClientPoolDM::getFromEP(TcrEndpoint* theEP) {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_queueLock);
-  for (auto itr = m_queue.begin(); itr != m_queue.end(); itr++) {
+  std::lock_guard<decltype(mutex_)> lock(mutex_);
+  for (auto itr = queue_.begin(); itr != queue_.end(); itr++) {
     if ((*itr)->getEndpointObject() == theEP) {
       LOGDEBUG("ThinClientPoolDM::getFromEP got connection");
       TcrConnection* retVal = *itr;
-      m_queue.erase(itr);
+      queue_.erase(itr);
       return retVal;
     }
   }
@@ -2141,15 +2148,15 @@ TcrConnection* ThinClientPoolDM::getFromEP(TcrEndpoint* theEP) {
 }
 
 void ThinClientPoolDM::removeEPConnections(TcrEndpoint* theEP) {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_queueLock);
-  auto size = static_cast<int32_t>(m_queue.size());
+  std::lock_guard<decltype(mutex_)> lock(mutex_);
+  auto size = static_cast<int32_t>(queue_.size());
   int numConn = 0;
 
   while (size--) {
-    TcrConnection* curConn = m_queue.back();
-    m_queue.pop_back();
+    TcrConnection* curConn = queue_.back();
+    queue_.pop_back();
     if (curConn->getEndpointObject() != theEP) {
-      m_queue.push_front(curConn);
+      queue_.push_front(curConn);
     } else {
       curConn->close();
       _GEODE_SAFE_DELETE(curConn);
@@ -2165,10 +2172,10 @@ TcrConnection* ThinClientPoolDM::getNoGetLock(
     bool& maxConnLimit) {
   TcrConnection* returnT = nullptr;
   {
-    ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_queueLock);
+    std::lock_guard<decltype(mutex_)> lock(mutex_);
 
     do {
-      returnT = popFromQueue(isClosed);
+      returnT = popNoLock(isClosed);
       if (returnT) {
         if (excludeConnection(returnT, excludeServers)) {
           returnT->close();
@@ -2191,7 +2198,7 @@ TcrConnection* ThinClientPoolDM::getNoGetLock(
 }
 
 void ThinClientPoolDM::incRegionCount() {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_queueLock);
+  std::lock_guard<decltype(mutex_)> lock(mutex_);
 
   if (!m_isDestroyed && !m_destroyPending) {
     m_numRegions++;
@@ -2201,13 +2208,13 @@ void ThinClientPoolDM::incRegionCount() {
 }
 
 void ThinClientPoolDM::decRegionCount() {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> _guard(m_queueLock);
+  std::lock_guard<decltype(mutex_)> lock(mutex_);
 
   m_numRegions--;
 }
 
 void ThinClientPoolDM::checkRegions() {
-  ACE_Guard<ACE_Recursive_Thread_Mutex> guard(m_queueLock);
+  std::lock_guard<decltype(mutex_)> lock(mutex_);
 
   if (m_numRegions > 0) {
     throw IllegalStateException(
@@ -2240,7 +2247,7 @@ GfErrType ThinClientPoolDM::doFailover(TcrConnection* conn) {
         break;
       }
       case TcrMessage::EXCEPTION: {
-        const char* exceptionMsg = reply.getException();
+        const auto& exceptionMsg = reply.getException();
         err = ThinClientRegion::handleServerException(
             "CacheTransactionManager::failover", exceptionMsg);
         break;
@@ -2311,7 +2318,7 @@ TcrConnection* ThinClientPoolDM::getConnectionFromQueueW(
       // if all buckets are not initialized
       //  match = true;
     }
-    if (slTmp != nullptr && m_clientMetadataService != nullptr) {
+    if (slTmp != nullptr && m_clientMetadataService) {
       if (m_clientMetadataService->isBucketMarkedForTimeout(
               request.getRegionName().c_str(), slTmp->getBucketId())) {
         *error = GF_CLIENT_WAIT_TIMEOUT;
@@ -2324,11 +2331,11 @@ TcrConnection* ThinClientPoolDM::getConnectionFromQueueW(
   if (theEP != nullptr) {
     conn = getFromEP(theEP);
     if (!conn) {
-      LOGFINER("Creating connection to endpint as not found in pool ");
+      LOGFINER("Creating connection to endpoint as not found in pool ");
       *error = createPoolConnectionToAEndPoint(conn, theEP, maxConnLimit, true);
       if (*error == GF_CLIENT_WAIT_TIMEOUT ||
           *error == GF_CLIENT_WAIT_TIMEOUT_REFRESH_PRMETADATA) {
-        if (m_clientMetadataService == nullptr || request.getKey() == nullptr) {
+        if (!m_clientMetadataService || request.getKey() == nullptr) {
           return nullptr;
         }
 
@@ -2343,6 +2350,8 @@ TcrConnection* ThinClientPoolDM::getConnectionFromQueueW(
                   version);
         }
         return nullptr;
+      } else {
+        removeEPFromMetadataIfError(*error, theEP);
       }
     }
   }
@@ -2407,7 +2416,7 @@ GfErrType FunctionExecution::execute() {
   m_error = m_poolDM->sendRequestToEP(request, reply, m_ep);
   m_error = m_poolDM->handleEPError(m_ep, reply, m_error);
   if (m_error != GF_NOERR) {
-    if (m_error == GF_NOTCON || m_error == GF_IOERR) {
+    if (m_error == GF_NOTCON) {
       return GF_NOERR;  // if server is unavailable its not an error for
       // functionexec OnServers() case
     }
