@@ -67,13 +67,6 @@ class CredentialGenerator;
  * Different implementations are there for different kinds of authentication/
  * authorization schemes.
  * <p>
- * Usage:
- *   auto cg = CredentialGenerator::create( schemeStr );
- *   @param schemeStr can be one of the following
- *    DUMMY - simple username/password authentication
- *    LDAP  - LDAP server based authentication.
- *    PKCS  - Digital signature based authentication
- *    NONE  - Disable security altogether.
  *
  * for client connection credentials
  *   cg->getAuthInit(prop);
@@ -93,10 +86,10 @@ class CredentialGenerator {
   std::string m_name;
   static registeredClassMap* generatormap;
 
-  CredentialGenerator() : m_id(ID_NONE), m_name("NONE"){};
+  CredentialGenerator() : m_id(ID_NONE), m_name("NONE") {}
 
  protected:
-  CredentialGenerator(ID id, std::string name) : m_id(id), m_name(name){};
+  CredentialGenerator(ID id, std::string name) : m_id(id), m_name(name) {}
   CredentialGenerator(const CredentialGenerator& other)
       : m_id(other.m_id), m_name(other.m_name) {}
 
@@ -115,9 +108,17 @@ class CredentialGenerator {
       return false;
     }
     return (m_id == other->m_id && m_name == other->m_name);
-  };
+  }
 
  public:
+  /**
+   * @brief create new Credential Generator
+   * @param scheme can be one of the following
+   *    DUMMY - simple username/password authentication
+   *    LDAP  - LDAP server based authentication.
+   *    PKCS  - Digital signature based authentication
+   *    NONE  - Disable security altogether.
+   * **/
   static std::shared_ptr<CredentialGenerator> create(std::string scheme);
   static bool registerScheme(std::shared_ptr<CredentialGenerator> scheme) {
     // if not already registered...
@@ -153,7 +154,7 @@ class CredentialGenerator {
     }
   }
 
-  void hashCode(){};
+  void hashCode() {}
 
   void getAuthInit(std::shared_ptr<Properties>& prop) {
     std::string authinit = this->getClientAuthInitLoaderFactory();
